@@ -163,15 +163,15 @@ public class ProjectsCaller {
 	/**
 	 * Gets the relationship chain.
 	 *
-	 * @param profileID the profile ID
-	 * @param projectID the project ID
+	 * @param profileID  the profile ID
+	 * @param projectID  the project ID
 	 * @param relationID the relation ID
-	 * @param deep the deep
+	 * @param deep       the deep
 	 * @return the relationship chain
 	 * @throws Exception the exception
 	 */
-	public Iterator<RelationshipNavigationObject> getRelationshipChain(String profileID, String projectID, String relationID, Boolean deep)
-			throws Exception {
+	public Iterator<RelationshipNavigationObject> getRelationshipChain(String profileID, String projectID,
+			String relationID, Boolean deep) throws Exception {
 		LOG.info("getRelationshipChain called for projectID: {}, relationID: {}", projectID, projectID);
 		Projects<Project> client = (Projects<Project>) getClient(profileID);
 		return client.getRelationshipChain(projectID, relationID, deep);
@@ -347,11 +347,11 @@ public class ProjectsCaller {
 	/**
 	 * Creates the relationship.
 	 *
-	 * @param fromProfileID    the from profile ID
-	 * @param fromProjectID    the from project ID
+	 * @param fromProfileID  the from profile ID
+	 * @param fromProjectID  the from project ID
 	 * @param relationshipId the relationship id
-	 * @param toProfileID      the to profile ID
-	 * @param toProjectID      the to project ID
+	 * @param toProfileID    the to profile ID
+	 * @param toProjectID    the to project ID
 	 * @throws RemoteException the remote exception
 	 */
 	public void createRelationship(String fromProfileID, String fromProjectID, String relationshipId,
@@ -391,11 +391,37 @@ public class ProjectsCaller {
 		client.deleteRelation(request);
 	}
 
+	/**
+	 * Delete fileset.
+	 *
+	 * @param profileID         the profile ID
+	 * @param projectID         the project ID
+	 * @param jsonPathToFileset the json path to fileset
+	 * @param force             the force
+	 * @param ignoreErrors the ignore errors
+	 * @return the project
+	 * @throws RemoteException the remote exception
+	 */
+	public Project deleteFileset(String profileID, String projectID, String jsonPathToFileset, Boolean force, Boolean ignoreErrors)
+			throws RemoteException {
+		LOG.info("deleteFileset called for profileID {} and projectID {}, fileset path: {}", profileID, projectID,
+				jsonPathToFileset);
+
+		Projects<Project> client = (Projects<Project>) getClient(profileID);
+
+		ignoreErrors = ignoreErrors==null?false:ignoreErrors;
+		
+		Project project = client.deleteFileSet(projectID, jsonPathToFileset, force, ignoreErrors);
+		LOG.info("fileset {} deleted", jsonPathToFileset);
+		LOG.debug("returning new project: {} ", project.getTheDocument());
+		return project;
+	}
+
 	/**
 	 * Simple query.
 	 *
 	 * @param profileID the profile ID
-	 * @param filter the filter
+	 * @param filter    the filter
 	 * @return the iterator
 	 * @throws Exception the exception
 	 */
@@ -428,7 +454,7 @@ public class ProjectsCaller {
 	 */
 	public Iterator<Project> queryOnMongo(String profileID, Integer totalItems, Integer offset, Integer limit,
 			SearchingFilter filter) throws Exception {
-		LOG.info("queryOnMongo called");
+		LOG.debug("queryOnMongo called");
 
 		try {
 
